# Chalk Creek at Coalville, UT (section control)

## USGS Gage ID: 10131000

## Control
The streambed is composed of gravel, sand, and silt.
The channel is straight for 150 feet above the gage and 100 feet below the station.
The banks are fairly steep through the gage reach, especially the left bank.
The right bank is fairly protected from erosion due to an abundance of willow and cottonwood trees that grow along the bank.
A concrete Ogee weir is the hydraulic control for all but the highest of flows which are under channel control.

## Stage Ranges
- Section control: 2.88 to 4 ft